==> mcss-0.0.31.tar.gz: mcss-0.0.31/mcss/Rule.cpp <==
// rule class definitions
// copyright 2008, 2009 jamie twycross, jpt AT cs.nott.ac.uk
// released under GNU GPL version 3

#if HAVE_CONFIG_H
	#include <config.h>
#endif

#include "Rule.h"

#include <iostream>
#include <ecsb/ecsb.h>
#include <stdlib.h>

using namespace Simulation;
using namespace ECSB;

// constructor
Simulation::Rule::Rule(std::string s)
{
	id = s;
	name = "";
	channel = diffusion = false;
	diffusion = distribution = false;
	c = D = h = br = st = 0.0;
	N = 0;
	num_reactants = num_products = 0;
	vector[0] = vector[1] = vector[2] = 0;
	initial_reactant[0] = initial_reactant[1] = 0;
	initial_product[0] = initial_product[1] = initial_product[2] = 0;
	target_name = target_type = "";
}

// destructor
Simulation::Rule::~Rule()
{
}

// general access methods
void Simulation::Rule::setReactionConstant(double rc) { c = rc; }
int Simulation::Rule::isChannel(void) { return channel; }
unsigned long Simulation::Rule::getReactantIndex(unsigned long ind) \
		{ return reactant[ind]; }
void Simulation::Rule::setReactantIndex(unsigned long ind, unsigned long i) \
		{ reactant[ind] = i; }
unsigned long Simulation::Rule::getProductIndex(unsigned long ind) \
		{ return product[ind]; }
void Simulation::Rule::setProductIndex(unsigned long ind, unsigned long i) \
		{ product[ind] = i; }
void Simulation::Rule::setChannel(void) { channel = true; }
void Simulation::Rule::setXVector(long int i) { vector[0] = i; }
void Simulation::Rule::setYVector(long int i) { vector[1] = i; }
void Simulation::Rule::setZVector(long int i) { vector[2] = i; }
long int Simulation::Rule::getXVector(void) { return vector[0]; }
long int Simulation::Rule::getYVector(void) { return vector[1]; }
long int Simulation::Rule::getZVector(void) { return vector[2]; }
void Simulation::Rule::setPropensity(double p) { propensity = p; }
double Simulation::Rule::getPropensity(void) { return propensity; }
std::string Simulation::Rule::getId(void) { return id; }
void Simulation::Rule::setId(std::string s) { id = s; }
std::string Simulation::Rule::getName(void) { return name; }
void Simulation::Rule::setName(std::string s) { name = s; }
const char *Simulation::Rule::getNameStr(void) { return name.c_str(); }
unsigned long Simulation::Rule::getNumReactants(void) { return num_reactants; }
void Simulation::Rule::setNumReactants(unsigned long i) { num_reactants = i; }
unsigned long Simulation::Rule::getNumProducts(void) { return num_products; }
void Simulation::Rule::setNumProducts(unsigned long i) { num_products = i; }
bool Simulation::Rule::isDiffusion(void) { return diffusion; }
bool Simulation::Rule::isDistribution(void) { return distribution; }
void Simulation::Rule::setDiffusionConstant(double v) { D = v; }
double Simulation::Rule::getDiffusionConstant(void) { return D; }
void Simulation::Rule::setDiffusionLength(double v) { h = v; }
double Simulation::Rule::getDiffusionLength(void) { return h; }
void Simulation::Rule::setDiffusionNumber(unsigned int v) { N = v; }
unsigned int Simulation::Rule::getDiffusionNumber(void) { return N; }
void Simulation::Rule::setDiffusionBaseRate(double v) { br = v; }
double Simulation::Rule::getDiffusionBaseRate(void) { return br; }
void Simulation::Rule::setDiffusionStart(double v) { st = v; }
double Simulation::Rule::getDiffusionStart(void) { return st; }
void Simulation::Rule::setTargetName(std::string s) { target_name = s; }
std::string Simulation::Rule::getTargetName(void) { return target_name; }
void Simulation::Rule::setTargetType(std::string s) { target_name = s; }
std::string Simulation::Rule::getTargetType(void) { return target_name; }
void Simulation::Rule::setInitialReactant(unsigned long i, unsigned long v) \
		{ initial_reactant[i] = v; }
unsigned long Simulation::Rule::getInitialReactant(unsigned long i) \
		{ return initial_reactant[i]; }
void Simulation::Rule::setInitialProduct(unsigned long i, unsigned long v) \
		{ initial_product[i] = v; }
unsigned long Simulation::Rule::getInitialProduct(unsigned long i) \
		{ return initial_product[i]; }

void Simulation::Rule::show(void)
{
	unsigned long i;

	std::cout << "id=" << id;
	std::cout << " c=" << c;
	std::cout << " x=" << vector[0];
	std::cout << " y=" << vector[1];
	std::cout << " r=" << reactant;
	for(i = 0; i < num_reactants; i++) {
		if(i)
			std::cout << ",";
		std::cout << reactant[i];
	}
	std::cout << " p=" << product;
	for(i = 0; i < num_products; i++) {
		if(i)
			std::cout << ",";
		std::cout << product[i];
	}
	std::cout << "\n";
}

// set rule as diffusion rule
// call after the all the diffusion parameters (D, h, N) have been set
void Simulation::Rule::setDiffusion(void)
{
	diffusion = true;
	br = D / (h * h);  // set base rate
}

// set distribution-based reaction constant parameters
void Simulation::Rule::setDistribution(std::string s)
{
	std::string sc, scc;
	char *endptr;

	// set flag
	distribution = true;

	// set distribution
	sc = s.substr(0, s.find(':'));
	if(sc == "gaussian")
		distribution_type = GAUSSIAN_DISTRIBUTION;

	// set distribution mean
	sc = s.substr(s.find(':') + 1);
	distribution_mean = strtod(sc.c_str(), &endptr);

	// set distribution standard deviation
	scc = sc.substr(sc.find(':') + 1);
	distribution_sd = strtod(scc.c_str(), &endptr);
}

// return reaction constant
double Simulation::Rule::getReactionConstant(void)
{
	if(distribution)
		switch(distribution_type) {
			case GAUSSIAN_DISTRIBUTION:
				return gaussianRandomNumberNN(distribution_mean, \
						distribution_sd);
				break;

			default:
				std::cerr << "error: unknown distribution function\n";
				return 0.0;
				break;
		}

	return c;
}

==> mcss-0.0.39.tar.gz: mcss-0.0.39/mcss/Rule.cpp <==
// rule class definitions
// copyright 2008, 2009 jamie twycross, jpt AT cs.nott.ac.uk
// released under GNU GPL version 3

#if HAVE_CONFIG_H
	#include <config.h>
#endif

#include "Rule.h"

#include <iostream>
#include <ecsb/ecsb.h>
#include <stdlib.h>

using namespace Simulation;
using namespace ECSB;

// constructor
Simulation::Rule::Rule(std::string s)
{
	id = s;
	name = "";
	channel = diffusion = false;
	diffusion = distribution = false;
	c = D = h = br = st = 0.0;
	N = 0;
	num_reactants = num_products = 0;
	vector[0] = vector[1] = vector[2] = 0;
	initial_reactant[0] = initial_reactant[1] = 0;
	initial_product[0] = initial_product[1] = initial_product[2] = 0;
	target_name = target_type = "";
}

// destructor
Simulation::Rule::~Rule()
{
}

// general access methods
void Simulation::Rule::setReactionConstant(double rc) { c = rc; }
int Simulation::Rule::isChannel(void) { return channel; }
unsigned long Simulation::Rule::getReactantIndex(unsigned long ind) \
		{ return reactant[ind]; }
void Simulation::Rule::setReactantIndex(unsigned long ind, unsigned long i) \
		{ reactant[ind] = i; }
unsigned long Simulation::Rule::getProductIndex(unsigned long ind) \
		{ return product[ind]; }
void Simulation::Rule::setProductIndex(unsigned long ind, unsigned long i) \
		{ product[ind] = i; }
void Simulation::Rule::setChannel(void) { channel = true; }
void Simulation::Rule::setXVector(long int i) { vector[0] = i; }
void Simulation::Rule::setYVector(long int i) { vector[1] = i; }
void Simulation::Rule::setZVector(long int i) { vector[2] = i; }
long int Simulation::Rule::getXVector(void) { return vector[0]; }
long int Simulation::Rule::getYVector(void) { return vector[1]; }
long int Simulation::Rule::getZVector(void) { return vector[2]; }
void Simulation::Rule::setPropensity(double p) { propensity = p; }
double Simulation::Rule::getPropensity(void) { return propensity; }
std::string Simulation::Rule::getId(void) { return id; }
void Simulation::Rule::setId(std::string s) { id = s; }
std::string Simulation::Rule::getName(void) { return name; }
void Simulation::Rule::setName(std::string s) { name = s; }
const char *Simulation::Rule::getNameStr(void) { return name.c_str(); }
unsigned long Simulation::Rule::getNumReactants(void) { return num_reactants; }
void Simulation::Rule::setNumReactants(unsigned long i) { num_reactants = i; }
unsigned long Simulation::Rule::getNumProducts(void) { return num_products; }
void Simulation::Rule::setNumProducts(unsigned long i) { num_products = i; }
bool Simulation::Rule::isDiffusion(void) { return diffusion; }
bool Simulation::Rule::isDistribution(void) { return distribution; }
void Simulation::Rule::setDiffusionConstant(double v) { D = v; }
double Simulation::Rule::getDiffusionConstant(void) { return D; }
void Simulation::Rule::setDiffusionLength(double v) { h = v; }
double Simulation::Rule::getDiffusionLength(void) { return h; }
void Simulation::Rule::setDiffusionNumber(unsigned int v) { N = v; }
unsigned int Simulation::Rule::getDiffusionNumber(void) { return N; }
void Simulation::Rule::setDiffusionBaseRate(double v) { br = v; }
double Simulation::Rule::getDiffusionBaseRate(void) { return br; }
void Simulation::Rule::setDiffusionStart(double v) { st = v; }
double Simulation::Rule::getDiffusionStart(void) { return st; }
void Simulation::Rule::setTargetName(std::string s) { target_name = s; }
std::string Simulation::Rule::getTargetName(void) { return target_name; }
void Simulation::Rule::setTargetType(std::string s) { target_type = s; }
std::string Simulation::Rule::getTargetType(void) { return target_type; }
void Simulation::Rule::setInitialReactant(unsigned long i, unsigned long v) \
		{ initial_reactant[i] = v; }
unsigned long Simulation::Rule::getInitialReactant(unsigned long i) \
		{ return initial_reactant[i]; }
void Simulation::Rule::setInitialProduct(unsigned long i, unsigned long v) \
		{ initial_product[i] = v; }
unsigned long Simulation::Rule::getInitialProduct(unsigned long i) \
		{ return initial_product[i]; }

void Simulation::Rule::show(void)
{
	unsigned long i;

	std::cout << "id=" << id;
	std::cout << " c=" << c;
	std::cout << " x=" << vector[0];
	std::cout << " y=" << vector[1];
	std::cout << " r=";
	for(i = 0; i < num_reactants; i++) {
		if(i)
			std::cout << ",";
		std::cout << reactant[i];
	}
	std::cout << " p=";
	for(i = 0; i < num_products; i++) {
		if(i)
			std::cout << ",";
		std::cout << product[i];
	}
	std::cout << "\n";
}

// set rule as diffusion rule
// call after the all the diffusion parameters (D, h, N) have been set
void Simulation::Rule::setDiffusion(void)
{
	diffusion = true;
	br = D / (h * h);  // set base rate
}

// set distribution-based reaction constant parameters
void Simulation::Rule::setDistribution(std::string s)
{
	std::string sc, scc;
	char *endptr;

	// set flag
	distribution = true;

	// set distribution
	sc = s.substr(0, s.find(':'));
	if(sc == "gaussian")
		distribution_type = GAUSSIAN_DISTRIBUTION;

	// set distribution mean
	sc = s.substr(s.find(':') + 1);
	distribution_mean = strtod(sc.c_str(), &endptr);

	// set distribution standard deviation
	scc = sc.substr(sc.find(':') + 1);
	distribution_sd = strtod(scc.c_str(), &endptr);
}

// return reaction constant
double Simulation::Rule::getReactionConstant(void)
{
	if(distribution)
		switch(distribution_type) {
			case GAUSSIAN_DISTRIBUTION:
				return gaussianRandomNumberNN(distribution_mean, \
						distribution_sd);
				break;

			default:
				std::cerr << "error: unknown distribution function\n";
				return 0.0;
				break;
		}

	return c;
}
